pub struct Context<A> { /* private fields */ }Expand description
A cloneable context for the actor.
Currently this fuctions as a means by which to alter the state of the Executor, it is
cloneable and can thus be sent to other threads, runtimes or even other actors to trigger a
shutdown.
Implementations
Sourceimpl<A> Context<A>
impl<A> Context<A>
Sourcepub fn shutdown(&self)
pub fn shutdown(&self)
Triggers the end of the executor.
Once triggered, no new messages will be processed and the actor will exit after resolving
Actor::stopping
Sourcepub fn address(&self) -> &WeakAddress<A>
pub fn address(&self) -> &WeakAddress<A>
Retrieve the address for the executor’s actor
This is useful when an actor wants to emit messages to itself.