pub struct Mailbox<T: Message> { /* private fields */ }Expand description
A type-erased, cloneable handle for sending messages of type T to an actor.
Unlike Address<A>, Mailbox<T> is generic over the message type rather than the actor
type. This allows passing a mailbox to code that only needs to send a specific message type
without exposing the concrete actor A.
Construct a Mailbox<T> from an Address<A> via Address::into_mailbox.
Implementations